#!/usr/bin/env sh
set -e

# https://www.lua.org/tests/
# There are two sets:
# 1. basic
# 2. complete
#
# The basic subset is selected by passing -e'_U=true'
# The complete set is noted to contain tests that may consume too much memory or have non-portable tests.
# attrib.lua for example needs some multilib customization (have to compile the stuff in libs/ for each ABI)

cd "${srcdir}"/tests && "${LUA}" -e_U=true $(basename ${1})
